# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: requests.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'requests.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from . import task_pb2 as task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0erequests.proto\x12\x17hyrex.performanceserver\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\ntask.proto\"\x9d\x04\n\x12\x45nqueueTaskRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ndurable_id\x18\x02 \x01(\t\x12\x0f\n\x07root_id\x18\x03 \x01(\t\x12\x1c\n\x0fworkflow_run_id\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x15workflow_dependencies\x18\x05 \x03(\t\x12\x16\n\tparent_id\x18\x06 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x06status\x18\x07 \x01(\x0e\x32#.hyrex.performanceserver.TaskStatus\x12\x11\n\ttask_name\x18\x08 \x01(\t\x12\x0c\n\x04\x61rgs\x18\t \x01(\x0c\x12\r\n\x05queue\x18\n \x01(\t\x12\x13\n\x0bmax_retries\x18\x0b \x01(\x05\x12\x33\n\x08priority\x18\x0c \x01(\x0e\x32!.hyrex.performanceserver.Priority\x12\x1c\n\x0ftimeout_seconds\x18\r \x01(\x05H\x02\x88\x01\x01\x12\x1c\n\x0fidempotency_key\x18\x0e \x01(\tH\x03\x88\x01\x01\x12\x38\n\x0fscheduled_start\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04\x88\x01\x01\x42\x12\n\x10_workflow_run_idB\x0c\n\n_parent_idB\x12\n\x10_timeout_secondsB\x12\n\x10_idempotency_keyB\x12\n\x10_scheduled_start\"&\n\x13\x45nqueueTaskResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"8\n\x12\x44\x65queueTaskRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\r\n\x05queue\x18\x02 \x01(\t\"V\n\x13\x44\x65queueTaskResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12.\n\x04task\x18\x02 \x01(\x0b\x32 .hyrex.performanceserver.TaskRun\";\n\x10GetQueuesRequest\x12\x16\n\x0emax_num_queues\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"4\n\x11GetQueuesResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06queues\x18\x02 \x03(\t\"$\n\x11GetTaskRunRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"U\n\x12GetTaskRunResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12.\n\x04task\x18\x02 \x01(\x0b\x32 .hyrex.performanceserver.TaskRun\"\'\n\x14GetTaskStatusRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"]\n\x15GetTaskStatusResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x33\n\x06status\x18\x02 \x01(\x0e\x32#.hyrex.performanceserver.TaskStatus\"E\n\x12MarkSuccessRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x13\n\x06result\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_result\"&\n\x13MarkSuccessResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"$\n\x11MarkFailedRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"%\n\x12MarkFailedResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"/\n\x19GetDurableRunTasksRequest\x12\x12\n\ndurable_id\x18\x01 \x01(\t\"^\n\x1aGetDurableRunTasksResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12/\n\x05tasks\x18\x02 \x03(\x0b\x32 .hyrex.performanceserver.TaskRun\"6\n\x11SetLogLinkRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x10\n\x08log_link\x18\x02 \x01(\t\"%\n\x12SetLogLinkResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"E\n\x16RegisterTaskDefRequest\x12+\n\x04task\x18\x01 \x01(\x0b\x32\x1d.hyrex.performanceserver.Task\"\x19\n\x17RegisterTaskDefResponse\"&\n\x11GetTaskDefRequest\x12\x11\n\ttask_name\x18\x01 \x01(\t\"A\n\x12GetTaskDefResponse\x12+\n\x04task\x18\x01 \x01(\x0b\x32\x1d.hyrex.performanceserver.Task\"\x17\n\x15GetAllTaskDefsRequest\"F\n\x16GetAllTaskDefsResponse\x12,\n\x05tasks\x18\x01 \x03(\x0b\x32\x1d.hyrex.performanceserver.Task\"\x15\n\x13RegisterCronRequest\"\x16\n\x14RegisterCronResponse\"\x81\x01\n\x17RegisterExecutorRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\x15\n\rexecutor_name\x18\x02 \x01(\t\x12\x15\n\rqueue_pattern\x18\x03 \x01(\t\x12\x0e\n\x06queues\x18\x04 \x03(\t\x12\x13\n\x0bworker_name\x18\x05 \x01(\t\"+\n\x18RegisterExecutorResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"B\n\x1bUpdateExecutorQueuesRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\x0e\n\x06queues\x18\x02 \x03(\t\"/\n\x1cUpdateExecutorQueuesResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"?\n\x12RegisterAppRequest\x12)\n\x08\x61pp_info\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"&\n\x13RegisterAppResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"D\n\x1b\x41\x63quireSchedulerLockRequest\x12\x13\n\x0bworker_name\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\"Q\n\x1c\x41\x63quireSchedulerLockResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x14\n\x07lock_id\x18\x02 \x01(\x05H\x00\x88\x01\x01\x42\n\n\x08_lock_id\"(\n\x15TestConnectionRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\")\n\x16TestConnectionResponse\x12\x0f\n\x07message\x18\x01 \x01(\tB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'requests_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_ENQUEUETASKREQUEST']._serialized_start=119
  _globals['_ENQUEUETASKREQUEST']._serialized_end=660
  _globals['_ENQUEUETASKRESPONSE']._serialized_start=662
  _globals['_ENQUEUETASKRESPONSE']._serialized_end=700
  _globals['_DEQUEUETASKREQUEST']._serialized_start=702
  _globals['_DEQUEUETASKREQUEST']._serialized_end=758
  _globals['_DEQUEUETASKRESPONSE']._serialized_start=760
  _globals['_DEQUEUETASKRESPONSE']._serialized_end=846
  _globals['_GETQUEUESREQUEST']._serialized_start=848
  _globals['_GETQUEUESREQUEST']._serialized_end=907
  _globals['_GETQUEUESRESPONSE']._serialized_start=909
  _globals['_GETQUEUESRESPONSE']._serialized_end=961
  _globals['_GETTASKRUNREQUEST']._serialized_start=963
  _globals['_GETTASKRUNREQUEST']._serialized_end=999
  _globals['_GETTASKRUNRESPONSE']._serialized_start=1001
  _globals['_GETTASKRUNRESPONSE']._serialized_end=1086
  _globals['_GETTASKSTATUSREQUEST']._serialized_start=1088
  _globals['_GETTASKSTATUSREQUEST']._serialized_end=1127
  _globals['_GETTASKSTATUSRESPONSE']._serialized_start=1129
  _globals['_GETTASKSTATUSRESPONSE']._serialized_end=1222
  _globals['_MARKSUCCESSREQUEST']._serialized_start=1224
  _globals['_MARKSUCCESSREQUEST']._serialized_end=1293
  _globals['_MARKSUCCESSRESPONSE']._serialized_start=1295
  _globals['_MARKSUCCESSRESPONSE']._serialized_end=1333
  _globals['_MARKFAILEDREQUEST']._serialized_start=1335
  _globals['_MARKFAILEDREQUEST']._serialized_end=1371
  _globals['_MARKFAILEDRESPONSE']._serialized_start=1373
  _globals['_MARKFAILEDRESPONSE']._serialized_end=1410
  _globals['_GETDURABLERUNTASKSREQUEST']._serialized_start=1412
  _globals['_GETDURABLERUNTASKSREQUEST']._serialized_end=1459
  _globals['_GETDURABLERUNTASKSRESPONSE']._serialized_start=1461
  _globals['_GETDURABLERUNTASKSRESPONSE']._serialized_end=1555
  _globals['_SETLOGLINKREQUEST']._serialized_start=1557
  _globals['_SETLOGLINKREQUEST']._serialized_end=1611
  _globals['_SETLOGLINKRESPONSE']._serialized_start=1613
  _globals['_SETLOGLINKRESPONSE']._serialized_end=1650
  _globals['_REGISTERTASKDEFREQUEST']._serialized_start=1652
  _globals['_REGISTERTASKDEFREQUEST']._serialized_end=1721
  _globals['_REGISTERTASKDEFRESPONSE']._serialized_start=1723
  _globals['_REGISTERTASKDEFRESPONSE']._serialized_end=1748
  _globals['_GETTASKDEFREQUEST']._serialized_start=1750
  _globals['_GETTASKDEFREQUEST']._serialized_end=1788
  _globals['_GETTASKDEFRESPONSE']._serialized_start=1790
  _globals['_GETTASKDEFRESPONSE']._serialized_end=1855
  _globals['_GETALLTASKDEFSREQUEST']._serialized_start=1857
  _globals['_GETALLTASKDEFSREQUEST']._serialized_end=1880
  _globals['_GETALLTASKDEFSRESPONSE']._serialized_start=1882
  _globals['_GETALLTASKDEFSRESPONSE']._serialized_end=1952
  _globals['_REGISTERCRONREQUEST']._serialized_start=1954
  _globals['_REGISTERCRONREQUEST']._serialized_end=1975
  _globals['_REGISTERCRONRESPONSE']._serialized_start=1977
  _globals['_REGISTERCRONRESPONSE']._serialized_end=1999
  _globals['_REGISTEREXECUTORREQUEST']._serialized_start=2002
  _globals['_REGISTEREXECUTORREQUEST']._serialized_end=2131
  _globals['_REGISTEREXECUTORRESPONSE']._serialized_start=2133
  _globals['_REGISTEREXECUTORRESPONSE']._serialized_end=2176
  _globals['_UPDATEEXECUTORQUEUESREQUEST']._serialized_start=2178
  _globals['_UPDATEEXECUTORQUEUESREQUEST']._serialized_end=2244
  _globals['_UPDATEEXECUTORQUEUESRESPONSE']._serialized_start=2246
  _globals['_UPDATEEXECUTORQUEUESRESPONSE']._serialized_end=2293
  _globals['_REGISTERAPPREQUEST']._serialized_start=2295
  _globals['_REGISTERAPPREQUEST']._serialized_end=2358
  _globals['_REGISTERAPPRESPONSE']._serialized_start=2360
  _globals['_REGISTERAPPRESPONSE']._serialized_end=2398
  _globals['_ACQUIRESCHEDULERLOCKREQUEST']._serialized_start=2400
  _globals['_ACQUIRESCHEDULERLOCKREQUEST']._serialized_end=2468
  _globals['_ACQUIRESCHEDULERLOCKRESPONSE']._serialized_start=2470
  _globals['_ACQUIRESCHEDULERLOCKRESPONSE']._serialized_end=2551
  _globals['_TESTCONNECTIONREQUEST']._serialized_start=2553
  _globals['_TESTCONNECTIONREQUEST']._serialized_end=2593
  _globals['_TESTCONNECTIONRESPONSE']._serialized_start=2595
  _globals['_TESTCONNECTIONRESPONSE']._serialized_end=2636
# @@protoc_insertion_point(module_scope)
